Hash the data structure of a dataset for a given column
Source:R/csfmt_rts_generics.R, R/csfmt_rts_v2.R
identify_data_structure.RdSummarises the data structure of a single column inside a dataset. For each
combination of granularity_time, granularity_geo, age, and sex it records
whether the column is structurally missing, only NA, only data, or a mix of
data and NA. The result can be passed to plot() for a visual overview.
Usage
identify_data_structure(x, col, ...)
# S3 method for class 'csfmt_rts_data_v2'
identify_data_structure(x, col, ...)
# S3 method for class '`tbl_Microsoft SQL Server`'
identify_data_structure(x, col, ...)Arguments
- x
An object of type
csfmt_rts_data_v2.- col
Column name (character) whose data structure is summarised.
- ...
Arguments passed to or from other methods.
Examples
cstidy::generate_test_data() %>%
cstidy::set_csfmt_rts_data_v2() %>%
cstidy::identify_data_structure("deaths_n") %>%
plot()